@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright 2019-2021 Ramil Nugmanov <nougmanoff@protonmail.com>
+#  Copyright 2019-2022 Ramil Nugmanov <nougmanoff@protonmail.com>
 #  This file is part of chython.
 #
 #  chython is free software; you can redistribute it and/or modify
@@ -19,13 +19,17 @@
 from collections import defaultdict
 from functools import cached_property
 from itertools import combinations
-from logging import info
+from logging import getLogger, INFO
 from typing import Dict, Set, Tuple, Union, TYPE_CHECKING
 from .graph import Stereo
 from ..morgan import _morgan
 from ...exceptions import AtomNotFound, IsChiral, NotChiral
 
 
+logger = getLogger('chython.stereo')
+logger.setLevel(INFO)
+
+
 if TYPE_CHECKING:
     from chython import MoleculeContainer
 
@@ -171,23 +175,31 @@ class MoleculeStereo(Stereo):
                 elif c not in self._chiral_allenes:
                     raise NotChiral
 
-                order = self._stereo_allenes[c]
                 t1, t2 = self._stereo_allenes_terminals[c]
-                w = order.index(m)
-                if w == 0:
-                    m1 = order[1]
-                    r = False
-                elif w == 1:
-                    m1 = order[0]
-                    t1, t2 = t2, t1
-                    r = False
-                elif w == 2:
-                    m1 = order[1]
+                order = self._stereo_allenes[c]
+                if self._atoms[m].atomic_number == 1:
+                    if t1 == n:
+                        m1 = order[1]
+                    else:
+                        t1, t2 = t2, t1
+                        m1 = order[0]
                     r = True
                 else:
-                    m1 = order[0]
-                    t1, t2 = t2, t1
-                    r = True
+                    w = order.index(m)
+                    if w == 0:
+                        m1 = order[1]
+                        r = False
+                    elif w == 1:
+                        m1 = order[0]
+                        t1, t2 = t2, t1
+                        r = False
+                    elif w == 2:
+                        m1 = order[1]
+                        r = True
+                    else:
+                        m1 = order[0]
+                        t1, t2 = t2, t1
+                        r = True
                 s = _allene_sign((*plane[m], mark), plane[t1], plane[t2], (*plane[m1], 0))
                 if s:
                     self._allenes_stereo[c] = s < 0 if r else s > 0
@@ -223,7 +235,7 @@ class MoleculeStereo(Stereo):
 
     def add_atom_stereo(self: 'MoleculeContainer', n: int, env: Tuple[int, ...], mark: bool, *, clean_cache=True):
         """
-        Add stereo data for specified neighbors bypass. Use it for tetrahedrons of allenes.
+        Add stereo data for specified neighbors bypass. Use it for tetrahedrons or allenes.
 
         :param n: number of tetrahedron atom or central atom of allene.
         :param env: numbers of atoms with specified bypass
@@ -378,7 +390,7 @@ class MoleculeStereo(Stereo):
             s = self._translate_allene_sign(n, *order[:2])
             v = _allene_sign((*plane[order[0]], 1), plane[order[2]], plane[order[3]], (*plane[order[1]], 0))
             if not v:
-                info(f'need 2d clean. wedge stereo ambiguous for atom {{{n}}}')
+                logger.info(f'need 2d clean. allenes wedge stereo ambiguous for atom {{{n}}}')
             if s:
                 wedge.append((order[2], order[0], v))
             else:
@@ -400,7 +412,7 @@ class MoleculeStereo(Stereo):
                 v = _pyramid_sign((*plane[order[3]], 0),
                                   (*plane[order[0]], 1), (*plane[order[1]], 0), (*plane[order[2]], 0))
             if not v:
-                info(f'need 2d clean. wedge stereo ambiguous for atom {{{n}}}')
+                logger.info(f'need 2d clean. tetrahedron wedge stereo ambiguous for atom {{{n}}}')
             if s:
                 wedge.append((n, order[0], v))
             else:
